==> Dressing_1.0.1.202504222255-1032.jar: src/testaccessoirconfigurator/Creatoraccessoirewizard.java <==
package testaccessoirconfigurator;

import java.util.ArrayList;
import java.util.List;
import org.eclipse.jface.wizard.IWizardPage;
import org.eclipse.jface.wizard.Wizard;


public class Creatoraccessoirewizard extends Wizard{
	
	
	public Globalaccessoirewizardpage globAccWiPage ;
	public Firstpartwizardpage firstWiPartPage ;
	public Secondpartwizardpage secondtWiPartPage;
	public Thirdpartwizardpage thirdtWiPartPage;
	public Accessoirdefinition accessoirbuild = new Accessoirdefinition();
	public List<IWizardPage> pages = new ArrayList<>();
	public Accessoirfilrmanager accessoireManager ;
	Creatoraccessoirewizard (){
		super();
		setWindowTitle("Création d'un objet");	
		this.accessoirbuild=Accessoirdefinition.getInstance();		
	}

	@Override
	public boolean performFinish() {
		Accessoirfilrmanager.write(accessoirbuild);
		return true;
	}
	@Override
	public void addPages() {
		globAccWiPage = new Globalaccessoirewizardpage("Createur Accessoire",this.accessoirbuild);
		firstWiPartPage = new Firstpartwizardpage("Première Partie");
		secondtWiPartPage= new Secondpartwizardpage("Deuxième Partie");
		thirdtWiPartPage = new Thirdpartwizardpage("Troisième Partie");
		addPage(globAccWiPage);
		addPage( firstWiPartPage);
		addPage(secondtWiPartPage);
		addPage(thirdtWiPartPage);
	
	}
	@Override
	public boolean canFinish() {
		IWizardPage[] pages = getPages();
		for (IWizardPage page : pages) {
			if (!page.isPageComplete()) {
				return false;
			}
		}
		return true;
	}

	  public void bind() {
	    	globAccWiPage.getComposite().addListener(firstWiPartPage.getFirstpartcomposite());
	    	globAccWiPage.getComposite().addListener(secondtWiPartPage.getSecondcomposite());
	    	globAccWiPage.getComposite().addListener(thirdtWiPartPage.getThirdcomposite());
	  }
}

==> Dressing_1.0.1.202505121749-1055.jar: src/testaccessoirconfigurator/Creatoraccessoirewizard.java <==
package testaccessoirconfigurator;

import java.util.ArrayList;
import java.util.List;
import org.eclipse.jface.wizard.IWizardPage;
import org.eclipse.jface.wizard.Wizard;


public class Creatoraccessoirewizard extends Wizard{
	
	
	public Globalaccessoirewizardpage globAccWiPage ;
	public Firstpartwizardpage firstWiPartPage ;
	public Secondpartwizardpage secondtWiPartPage;
	public Thirdpartwizardpage thirdtWiPartPage;
	public Accessoirdefinition accessoirbuild = new Accessoirdefinition();
	public List<IWizardPage> pages = new ArrayList<>();
	public Accessoirfilrmanager accessoireManager ;
	Creatoraccessoirewizard (){
		super();
		setWindowTitle("Création d'un Objet");	
		this.accessoirbuild=Accessoirdefinition.getInstance();		
	}

	@Override
	public boolean performFinish() {
		Accessoirfilrmanager.write(accessoirbuild);
		return true;
	}
	@Override
	public void addPages() {
		globAccWiPage = new Globalaccessoirewizardpage("Createur Accessoire",this.accessoirbuild);
		firstWiPartPage = new Firstpartwizardpage("Première Partie");
		secondtWiPartPage= new Secondpartwizardpage("Deuxième Partie");
		thirdtWiPartPage = new Thirdpartwizardpage("Troisième Partie");
		addPage(globAccWiPage);
		addPage( firstWiPartPage);
		addPage(secondtWiPartPage);
		addPage(thirdtWiPartPage);
	
	}
	@Override
	public boolean canFinish() {
		IWizardPage[] pages = getPages();
		for (IWizardPage page : pages) {
			if (!page.isPageComplete()) {
				return false;
			}
		}
		return true;
	}

	  public void bind() {
	    	globAccWiPage.getComposite().addListener(firstWiPartPage.getFirstpartcomposite());
	    	globAccWiPage.getComposite().addListener(secondtWiPartPage.getSecondcomposite());
	    	globAccWiPage.getComposite().addListener(thirdtWiPartPage.getThirdcomposite());
	  }
}
